# Arith Tools
Arith tools package for  basic arithmetic operations.

<i>In the arithmetic of love, one plus one equals everything, and two minus one equals nothing.</i>

Goals of the project: 
- Arith Tools is an arithmetic module which can be used to solve a very complicated arithmetic operations very easily.
- Arith Tools handles everything from the start of thinking of a very algorithm to it's end by just using this module.
- BLTAO, Bring Life To Arithmetic operations. Think of something more creative rather than wasting time in writing simpler code.

<br><br>

## How to install ?
<i>NOTE: It is recommended to set up a [virtual environment](https://pypi.org/project/virtualenv/).</i>

In order to install this module, you need to follow the command given below.
```bash
python -m pip install arith-tools
```

## Supported IDE

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `arith-tools` in your environment: `python -m pip install arith-tools`

Both type checking and auto-complete should work for thy service. No explicit type annotations required, write your code as usual.
<br><br>

### PyCharm
- Install `arith-tools` in your environment: `python -m pip install arith-tools`

Both type checking and auto-complete should work for thy service. No explicit type annotations required, write your code as usual. Auto-complete can be slow on big projects or if you have a lot of installed arith-tools submodules.
<br><br>

### IDLE
- Follow the same procedure as before.

<br><br>

## How to use the module ?
```bash
import arithtools
#To reverse a given number.
num=int(input("Enter a number: "))
print(arithtools.reverse(num))
```
## What are expected from Arith Tools ?

- Fibonacci Series.
- Reverse a given number.
- Convert a number to word.
- Check for Automorphic number.
- Check for Peterson Number.
- Check for sunny number.
- Check for Tech number.
- Check for Fascinating Number.
- Check for Keith or repfigit Number.
- Check for Neon Number.
- Check for Spy Number .
- Check for amicable number.
- Check for Terrace Number.......... and many more.
(Check out the Project to find more.)

<br>

### NOTE: Run ```help(arithtools)``` in interactive window or terminal to get more info. 

<br><br>

## Versioning
`arith-tools` version follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.


<br><br>

## Support and Contributing.

Developers are free to contribute to this open source projects and report bugs at any time in the `arith-tools` repository.